ALL_MODES=(
    ['prod']='docs/graphdash.yaml'
    ['test']='docs/graphdash.yaml'
)

ALL_PORTS=(
    ['prod']=1234
    ['test']=5678
)

WORKERS=3
TIMEOUT=60
